@@ -1,12 +1,10 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::TrialVersionComment;
-# git description: v0.002-1-g506e5e1
-$Dist::Zilla::Plugin::TrialVersionComment::VERSION = '0.003';
-# ABSTRACT: Add a # TRIAL comment after your version declaration in trial # releases
+package Dist::Zilla::Plugin::TrialVersionComment; # git description: v0.003-12-g095c87e
+# ABSTRACT: Add a "# TRIAL" comment after your version declaration in trial releases
 # KEYWORDS: plugin modules package version comment trial release
-# vim: set ts=8 sw=4 tw=78 et :
-
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+our $VERSION = '0.004';
 use Moose;
 with
     'Dist::Zilla::Role::PPI',
@@ -15,6 +13,7 @@ with
         { default_finders => [ ':InstallModules', ':ExecFiles' ] },
 ;
 use Module::Runtime 'module_notional_filename';
+use PPI::Document;
 use namespace::autoclean;
 
 sub munge_files
@@ -93,11 +92,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::TrialVersionComment - Add a # TRIAL comment after your version declaration in trial # releases
+Dist::Zilla::Plugin::TrialVersionComment - Add a "# TRIAL" comment after your version declaration in trial releases
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -186,4 +185,10 @@ This software is copyright (c) 2014 by Karen Etheridge.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTOR
+
+=for stopwords David Golden
+
+David Golden <dagolden@cpan.org>
+
 =cut
